# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from orbital_transfer.models.orbital_transfer_simulation_response_field_indexes_inner import OrbitalTransferSimulationResponseFieldIndexesInner
from orbital_transfer.models.orbital_transfer_simulation_response_orbital_ephemerides import OrbitalTransferSimulationResponseOrbitalEphemerides
from orbital_transfer.models.orbital_transfer_simulation_response_results import OrbitalTransferSimulationResponseResults
from orbital_transfer.models.orbital_transfer_simulation_response_spacecraft_states import OrbitalTransferSimulationResponseSpacecraftStates
from orbital_transfer.models.orbital_transfer_simulation_response_thrust_ephemerides import OrbitalTransferSimulationResponseThrustEphemerides
from typing import Optional, Set
from typing_extensions import Self

class OrbitalTransferSimulationResponse(BaseModel):
    """
    OrbitalTransferSimulationResponse
    """ # noqa: E501
    results: Optional[OrbitalTransferSimulationResponseResults] = None
    spacecraft_states: Optional[OrbitalTransferSimulationResponseSpacecraftStates] = Field(default=None, alias="spacecraftStates")
    ephemerides: Optional[List[List[Union[StrictFloat, StrictInt]]]] = Field(default=None, description="A list of all the requested ephemerides at each timestep")
    field_indexes: Optional[List[OrbitalTransferSimulationResponseFieldIndexesInner]] = Field(default=None, description="A map between the generated ephemerides labels and their indexes in the ephemerides array", alias="fieldIndexes")
    orbital_ephemerides: Optional[OrbitalTransferSimulationResponseOrbitalEphemerides] = Field(default=None, alias="orbitalEphemerides")
    thrust_ephemerides: Optional[OrbitalTransferSimulationResponseThrustEphemerides] = Field(default=None, alias="thrustEphemerides")
    errors: Optional[List[StrictStr]] = None
    warnings: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = ["results", "spacecraftStates", "ephemerides", "fieldIndexes", "orbitalEphemerides", "thrustEphemerides", "errors", "warnings"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrbitalTransferSimulationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of results
        if self.results:
            _dict['results'] = self.results.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spacecraft_states
        if self.spacecraft_states:
            _dict['spacecraftStates'] = self.spacecraft_states.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in field_indexes (list)
        _items = []
        if self.field_indexes:
            for _item in self.field_indexes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fieldIndexes'] = _items
        # override the default output from pydantic by calling `to_dict()` of orbital_ephemerides
        if self.orbital_ephemerides:
            _dict['orbitalEphemerides'] = self.orbital_ephemerides.to_dict()
        # override the default output from pydantic by calling `to_dict()` of thrust_ephemerides
        if self.thrust_ephemerides:
            _dict['thrustEphemerides'] = self.thrust_ephemerides.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrbitalTransferSimulationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "results": OrbitalTransferSimulationResponseResults.from_dict(obj["results"]) if obj.get("results") is not None else None,
            "spacecraftStates": OrbitalTransferSimulationResponseSpacecraftStates.from_dict(obj["spacecraftStates"]) if obj.get("spacecraftStates") is not None else None,
            "ephemerides": obj.get("ephemerides"),
            "fieldIndexes": [OrbitalTransferSimulationResponseFieldIndexesInner.from_dict(_item) for _item in obj["fieldIndexes"]] if obj.get("fieldIndexes") is not None else None,
            "orbitalEphemerides": OrbitalTransferSimulationResponseOrbitalEphemerides.from_dict(obj["orbitalEphemerides"]) if obj.get("orbitalEphemerides") is not None else None,
            "thrustEphemerides": OrbitalTransferSimulationResponseThrustEphemerides.from_dict(obj["thrustEphemerides"]) if obj.get("thrustEphemerides") is not None else None,
            "errors": obj.get("errors"),
            "warnings": obj.get("warnings")
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.circular_orbit import CircularOrbit

class TestCircularOrbit(unittest.TestCase):
    """CircularOrbit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CircularOrbit:
        """Test CircularOrbit
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CircularOrbit`
        """
        model = CircularOrbit()
        if include_optional:
            return CircularOrbit(
                inclination = 1.337,
                parameters = orbital_transfer.models.circular_orbit_parameters.CircularOrbitParameters(),
                advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                    orbit_date = '', 
                    ascending_node_type = 'RAAN', 
                    raan = 1.337, 
                    mltan = 1.337, 
                    anomaly = 1.337, 
                    anomaly_type = 'TRUE', 
                    orbital_element_type = 'MEAN', 
                    perigee_argument = 1.337, )
            )
        else:
            return CircularOrbit(
        )
        """

    def testCircularOrbit(self):
        """Test CircularOrbit"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from orbital_transfer.models.atmospheric_model import AtmosphericModel
from typing import Optional, Set
from typing_extensions import Self

class HarrisPriesterAtmosphericModel(AtmosphericModel):
    """
    HarrisPriesterAtmosphericModel
    """ # noqa: E501
    custom_solar_flux: Optional[Union[StrictFloat, StrictInt]] = Field(default=150.0, description="An optional averaged solar flux F10.7 to use for the Harris-Priester atmosphere model.", alias="customSolarFlux")
    __properties: ClassVar[List[str]] = ["type", "customSolarFlux"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of HarrisPriesterAtmosphericModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of HarrisPriesterAtmosphericModel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "customSolarFlux": obj.get("customSolarFlux") if obj.get("customSolarFlux") is not None else 150.0
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from orbital_transfer.models.advanced_orbit_parameters import AdvancedOrbitParameters
from orbital_transfer.models.analytical_orbital_transfer_request import AnalyticalOrbitalTransferRequest
from orbital_transfer.models.analytical_orbital_transfer_request_drag_perturbation import AnalyticalOrbitalTransferRequestDragPerturbation
from orbital_transfer.models.analytical_orbital_transfer_response import AnalyticalOrbitalTransferResponse
from orbital_transfer.models.atmospheric_model import AtmosphericModel
from orbital_transfer.models.axis import Axis
from orbital_transfer.models.body_solar_array import BodySolarArray
from orbital_transfer.models.box_spacecraft_geometry import BoxSpacecraftGeometry
from orbital_transfer.models.cartesian_ephemerides import CartesianEphemerides
from orbital_transfer.models.circular_altitude_orbit_parameters import CircularAltitudeOrbitParameters
from orbital_transfer.models.circular_ground_track_repeated_orbit_parameters import CircularGroundTrackRepeatedOrbitParameters
from orbital_transfer.models.circular_orbit import CircularOrbit
from orbital_transfer.models.circular_orbit_parameters import CircularOrbitParameters
from orbital_transfer.models.custom_maneuvering_strategy import CustomManeuveringStrategy
from orbital_transfer.models.deployable_fixed_solar_array import DeployableFixedSolarArray
from orbital_transfer.models.deployable_rotating_solar_array import DeployableRotatingSolarArray
from orbital_transfer.models.drag_perturbation import DragPerturbation
from orbital_transfer.models.duty_cycle_thrust_arc_definition import DutyCycleThrustArcDefinition
from orbital_transfer.models.earth_potential_perturbation import EarthPotentialPerturbation
from orbital_transfer.models.elliptical_ground_track_repeated_eccentricity_orbit_parameters import EllipticalGroundTrackRepeatedEccentricityOrbitParameters
from orbital_transfer.models.elliptical_orbit import EllipticalOrbit
from orbital_transfer.models.elliptical_orbit_parameters import EllipticalOrbitParameters
from orbital_transfer.models.elliptical_perigee_alt_apogee_alt_orbit_parameters import EllipticalPerigeeAltApogeeAltOrbitParameters
from orbital_transfer.models.elliptical_perigee_alt_eccentricity_orbit_parameters import EllipticalPerigeeAltEccentricityOrbitParameters
from orbital_transfer.models.elliptical_sma_eccentricity_orbit_parameters import EllipticalSmaEccentricityOrbitParameters
from orbital_transfer.models.geostationary_orbit import GeostationaryOrbit
from orbital_transfer.models.harris_priester_atmospheric_model import HarrisPriesterAtmosphericModel
from orbital_transfer.models.keplerian_ephemerides import KeplerianEphemerides
from orbital_transfer.models.mean_or_osculating_spacecraft_states import MeanOrOsculatingSpacecraftStates
from orbital_transfer.models.mean_or_osculating_spacecraft_states_attitude import MeanOrOsculatingSpacecraftStatesAttitude
from orbital_transfer.models.mean_or_osculating_spacecraft_states_pv_coordinates import MeanOrOsculatingSpacecraftStatesPvCoordinates
from orbital_transfer.models.nrlmsise00_atmospheric_model import NRLMSISE00AtmosphericModel
from orbital_transfer.models.orbit import Orbit
from orbital_transfer.models.orbital_transfer_simulation_request import OrbitalTransferSimulationRequest
from orbital_transfer.models.orbital_transfer_simulation_request_inputs import OrbitalTransferSimulationRequestInputs
from orbital_transfer.models.orbital_transfer_simulation_request_outputs import OrbitalTransferSimulationRequestOutputs
from orbital_transfer.models.orbital_transfer_simulation_request_outputs_orbital_ephemerides import OrbitalTransferSimulationRequestOutputsOrbitalEphemerides
from orbital_transfer.models.orbital_transfer_simulation_request_outputs_spacecraft_states import OrbitalTransferSimulationRequestOutputsSpacecraftStates
from orbital_transfer.models.orbital_transfer_simulation_request_outputs_thrust_ephemerides import OrbitalTransferSimulationRequestOutputsThrustEphemerides
from orbital_transfer.models.orbital_transfer_simulation_response import OrbitalTransferSimulationResponse
from orbital_transfer.models.orbital_transfer_simulation_response_field_indexes_inner import OrbitalTransferSimulationResponseFieldIndexesInner
from orbital_transfer.models.orbital_transfer_simulation_response_orbital_ephemerides import OrbitalTransferSimulationResponseOrbitalEphemerides
from orbital_transfer.models.orbital_transfer_simulation_response_orbital_ephemerides_mean import OrbitalTransferSimulationResponseOrbitalEphemeridesMean
from orbital_transfer.models.orbital_transfer_simulation_response_orbital_ephemerides_osculating import OrbitalTransferSimulationResponseOrbitalEphemeridesOsculating
from orbital_transfer.models.orbital_transfer_simulation_response_results import OrbitalTransferSimulationResponseResults
from orbital_transfer.models.orbital_transfer_simulation_response_spacecraft_states import OrbitalTransferSimulationResponseSpacecraftStates
from orbital_transfer.models.orbital_transfer_simulation_response_spacecraft_states_thrusting_inner import OrbitalTransferSimulationResponseSpacecraftStatesThrustingInner
from orbital_transfer.models.orbital_transfer_simulation_response_thrust_ephemerides import OrbitalTransferSimulationResponseThrustEphemerides
from orbital_transfer.models.perturbation import Perturbation
from orbital_transfer.models.platform import Platform
from orbital_transfer.models.propulsion_system import PropulsionSystem
from orbital_transfer.models.solar_array import SolarArray
from orbital_transfer.models.solar_array_face import SolarArrayFace
from orbital_transfer.models.spacecraft_geometry import SpacecraftGeometry
from orbital_transfer.models.spacecraft_geometry_dimension import SpacecraftGeometryDimension
from orbital_transfer.models.spherical_spacecraft_geometry import SphericalSpacecraftGeometry
from orbital_transfer.models.srp_perturbation import SrpPerturbation
from orbital_transfer.models.third_body_perturbation import ThirdBodyPerturbation
from orbital_transfer.models.thrust_arc_definition import ThrustArcDefinition
from orbital_transfer.models.thrust_arcs_positions import ThrustArcsPositions
from orbital_transfer.models.thrust_duration_thrust_arc_definition import ThrustDurationThrustArcDefinition



# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from orbital_transfer.models.thrust_arc_definition import ThrustArcDefinition
from typing import Optional, Set
from typing_extensions import Self

class CustomManeuveringStrategy(BaseModel):
    """
    A custom maneuvering strategy. Depending on the orbital elements changed in the  mission (semi-major axis, eccentricity, inclination, RAAN or argument of latitude), the user can change the number of thrust arcs (1 or 2),  their position, and the thrust pattern. 
    """ # noqa: E501
    number_of_rest_orbits: Optional[StrictInt] = Field(default=None, description="The number of rest orbits", alias="numberOfRestOrbits")
    number_of_thrust_orbits: Optional[StrictInt] = Field(default=None, description="The number of thrust orbits", alias="numberOfThrustOrbits")
    number_of_shift_orbits: Optional[StrictInt] = Field(default=None, description="The number of shift orbits", alias="numberOfShiftOrbits")
    thrust_arc: Optional[ThrustArcDefinition] = Field(default=None, alias="thrustArc")
    thrust_arcs_number: Optional[Annotated[int, Field(le=2, strict=True, ge=1)]] = Field(default=None, description="The number of thrust arcs", alias="thrustArcsNumber")
    stop_thrusting_during_eclipse: Optional[StrictBool] = Field(default=None, description="Indicates whether the spacecraft has to stop thrusting during eclipse", alias="stopThrustingDuringEclipse")
    dynamic_duty_cycle: Optional[StrictBool] = Field(default=None, description="Indicates whether the duty cycle is dynamic", alias="dynamicDutyCycle")
    __properties: ClassVar[List[str]] = ["numberOfRestOrbits", "numberOfThrustOrbits", "numberOfShiftOrbits", "thrustArc", "thrustArcsNumber", "stopThrustingDuringEclipse", "dynamicDutyCycle"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CustomManeuveringStrategy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of thrust_arc
        if self.thrust_arc:
            _dict['thrustArc'] = self.thrust_arc.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CustomManeuveringStrategy from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "numberOfRestOrbits": obj.get("numberOfRestOrbits"),
            "numberOfThrustOrbits": obj.get("numberOfThrustOrbits"),
            "numberOfShiftOrbits": obj.get("numberOfShiftOrbits"),
            "thrustArc": ThrustArcDefinition.from_dict(obj["thrustArc"]) if obj.get("thrustArc") is not None else None,
            "thrustArcsNumber": obj.get("thrustArcsNumber"),
            "stopThrustingDuringEclipse": obj.get("stopThrustingDuringEclipse"),
            "dynamicDutyCycle": obj.get("dynamicDutyCycle")
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class OrbitalTransferSimulationRequestOutputsOrbitalEphemerides(BaseModel):
    """
    Configuration of the interpolated ephemerides that have to be generated. 
    """ # noqa: E501
    types: Optional[List[StrictStr]] = Field(default=None, description="The types of ephemerides to generate. ")
    timestep: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The time step (in seconds) at which the ephemerides have to be generated.  This is the time step at which the ephemerides are interpolated.  The smaller the time step, the more accurate the ephemerides but the longer the computation time. ")
    mean: Optional[StrictBool] = Field(default=False, description="Indicates whether mean ephemerides have to be generated or not.  These elements account for secular and long periodic variations only.  This means that the short periodic effects (less than the orbital period) of  perturbations are filtered out. Thus, mean elements change slowly with time  (except for the anomaly). Usually they can be derived from analytical theories or  by numerical procedures.  Mean ephemerides request adds an extra step to the computation, so it may take longer. ")
    osculating: Optional[StrictBool] = Field(default=False, description="Indicates whether osculating ephemerides have to be generated or not.   Osculating elements are the instantaneous values of the orbital elements at a given time.  They are the most accurate representation of the orbit at a given time.   However, they are not suitable for long-term propagation because they are subject to  short-periodic variations due to perturbations. ")
    __properties: ClassVar[List[str]] = ["types", "timestep", "mean", "osculating"]

    @field_validator('types')
    def types_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['CARTESIAN', 'KEPLERIAN']):
                raise ValueError("each list item must be one of ('CARTESIAN', 'KEPLERIAN')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrbitalTransferSimulationRequestOutputsOrbitalEphemerides from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrbitalTransferSimulationRequestOutputsOrbitalEphemerides from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "types": obj.get("types"),
            "timestep": obj.get("timestep"),
            "mean": obj.get("mean") if obj.get("mean") is not None else False,
            "osculating": obj.get("osculating") if obj.get("osculating") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_analytical_post(self) -> None:
        """Test case for analytical_post

        Analytical Orbital Transfer
        """
        pass

    def test_compute_orbital_transfer_simulation(self) -> None:
        """Test case for compute_orbital_transfer_simulation

        Orbital transfer simulation
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from orbital_transfer.models.analytical_orbital_transfer_request import AnalyticalOrbitalTransferRequest
from orbital_transfer.models.analytical_orbital_transfer_response import AnalyticalOrbitalTransferResponse
from orbital_transfer.models.orbital_transfer_simulation_request import OrbitalTransferSimulationRequest
from orbital_transfer.models.orbital_transfer_simulation_response import OrbitalTransferSimulationResponse

from orbital_transfer.api_client import ApiClient, RequestSerialized
from orbital_transfer.api_response import ApiResponse
from orbital_transfer.rest import RESTResponseType


class DefaultApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def analytical_post(
        self,
        analytical_orbital_transfer_request: AnalyticalOrbitalTransferRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AnalyticalOrbitalTransferResponse:
        """Analytical Orbital Transfer

        Computes an analytical Orbital Transfer. 

        :param analytical_orbital_transfer_request: (required)
        :type analytical_orbital_transfer_request: AnalyticalOrbitalTransferRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._analytical_post_serialize(
            analytical_orbital_transfer_request=analytical_orbital_transfer_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AnalyticalOrbitalTransferResponse",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def analytical_post_with_http_info(
        self,
        analytical_orbital_transfer_request: AnalyticalOrbitalTransferRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AnalyticalOrbitalTransferResponse]:
        """Analytical Orbital Transfer

        Computes an analytical Orbital Transfer. 

        :param analytical_orbital_transfer_request: (required)
        :type analytical_orbital_transfer_request: AnalyticalOrbitalTransferRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._analytical_post_serialize(
            analytical_orbital_transfer_request=analytical_orbital_transfer_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AnalyticalOrbitalTransferResponse",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def analytical_post_without_preload_content(
        self,
        analytical_orbital_transfer_request: AnalyticalOrbitalTransferRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Analytical Orbital Transfer

        Computes an analytical Orbital Transfer. 

        :param analytical_orbital_transfer_request: (required)
        :type analytical_orbital_transfer_request: AnalyticalOrbitalTransferRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._analytical_post_serialize(
            analytical_orbital_transfer_request=analytical_orbital_transfer_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AnalyticalOrbitalTransferResponse",
            '400': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _analytical_post_serialize(
        self,
        analytical_orbital_transfer_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if analytical_orbital_transfer_request is not None:
            _body_params = analytical_orbital_transfer_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/analytical',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def compute_orbital_transfer_simulation(
        self,
        orbital_transfer_simulation_request: OrbitalTransferSimulationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> OrbitalTransferSimulationResponse:
        """Orbital transfer simulation

        Computes an orbital transfer simulation. 

        :param orbital_transfer_simulation_request: (required)
        :type orbital_transfer_simulation_request: OrbitalTransferSimulationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._compute_orbital_transfer_simulation_serialize(
            orbital_transfer_simulation_request=orbital_transfer_simulation_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrbitalTransferSimulationResponse",
            '400': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def compute_orbital_transfer_simulation_with_http_info(
        self,
        orbital_transfer_simulation_request: OrbitalTransferSimulationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[OrbitalTransferSimulationResponse]:
        """Orbital transfer simulation

        Computes an orbital transfer simulation. 

        :param orbital_transfer_simulation_request: (required)
        :type orbital_transfer_simulation_request: OrbitalTransferSimulationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._compute_orbital_transfer_simulation_serialize(
            orbital_transfer_simulation_request=orbital_transfer_simulation_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrbitalTransferSimulationResponse",
            '400': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def compute_orbital_transfer_simulation_without_preload_content(
        self,
        orbital_transfer_simulation_request: OrbitalTransferSimulationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Orbital transfer simulation

        Computes an orbital transfer simulation. 

        :param orbital_transfer_simulation_request: (required)
        :type orbital_transfer_simulation_request: OrbitalTransferSimulationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._compute_orbital_transfer_simulation_serialize(
            orbital_transfer_simulation_request=orbital_transfer_simulation_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrbitalTransferSimulationResponse",
            '400': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _compute_orbital_transfer_simulation_serialize(
        self,
        orbital_transfer_simulation_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if orbital_transfer_simulation_request is not None:
            _body_params = orbital_transfer_simulation_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/simulation',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "orbital-transfer"
VERSION = "2.2.0"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Orbital transfer API",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Orbital transfer API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Exotrail",
    long_description_content_type='text/markdown',
    long_description="""\
    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   &lt;b&gt;CHANGELOG&lt;/b&gt; &lt;ul&gt;   &lt;li&gt;&lt;b&gt;2.2.0&lt;/b&gt; - 2024-07-11 - Add space weather data source choice to &lt;b&gt;NRLMSISE00AtmosphericModel&lt;/b&gt; schema&lt;/li&gt;   &lt;li&gt;&lt;b&gt;2.1.0&lt;/b&gt; - 2024-07-03 - Add &lt;b&gt;atmosphericModel&lt;/b&gt; in &lt;b&gt;DragPerturbation&lt;/b&gt; schema&lt;/li&gt;   &lt;li&gt;&lt;b&gt;2.0.0&lt;/b&gt; - 2024-06-06 - Complete refactoring of the API&lt;/li&gt; &lt;/ul&gt; 
    """,  # noqa: E501
    package_data={"orbital_transfer": ["py.typed"]},
)



# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from importlib import import_module
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from orbital_transfer.models.box_spacecraft_geometry import BoxSpacecraftGeometry
    from orbital_transfer.models.spherical_spacecraft_geometry import SphericalSpacecraftGeometry

class SpacecraftGeometry(BaseModel):
    """
    If drag perturbation is request, the geometry of the spacecraft.
    """ # noqa: E501
    type: Optional[StrictStr] = Field(default=None, description="The type of spacecraft geometry")
    __properties: ClassVar[List[str]] = ["type"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['SPHERICAL', 'BOX']):
            raise ValueError("must be one of enum values ('SPHERICAL', 'BOX')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    # JSON field name that stores the object type
    __discriminator_property_name: ClassVar[str] = 'type'

    # discriminator mappings
    __discriminator_value_class_map: ClassVar[Dict[str, str]] = {
        'BOX': 'BoxSpacecraftGeometry','SPHERICAL': 'SphericalSpacecraftGeometry'
    }

    @classmethod
    def get_discriminator_value(cls, obj: Dict[str, Any]) -> Optional[str]:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Union[BoxSpacecraftGeometry, SphericalSpacecraftGeometry]]:
        """Create an instance of SpacecraftGeometry from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Optional[Union[BoxSpacecraftGeometry, SphericalSpacecraftGeometry]]:
        """Create an instance of SpacecraftGeometry from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type ==  'BoxSpacecraftGeometry':
            return import_module("orbital_transfer.models.box_spacecraft_geometry").BoxSpacecraftGeometry.from_dict(obj)
        if object_type ==  'SphericalSpacecraftGeometry':
            return import_module("orbital_transfer.models.spherical_spacecraft_geometry").SphericalSpacecraftGeometry.from_dict(obj)

        raise ValueError("SpacecraftGeometry failed to lookup discriminator value from " +
                            json.dumps(obj) + ". Discriminator property name: " + cls.__discriminator_property_name +
                            ", mapping: " + json.dumps(cls.__discriminator_value_class_map))





# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from orbital_transfer.models.mean_or_osculating_spacecraft_states import MeanOrOsculatingSpacecraftStates
from orbital_transfer.models.orbital_transfer_simulation_response_spacecraft_states_thrusting_inner import OrbitalTransferSimulationResponseSpacecraftStatesThrustingInner
from typing import Optional, Set
from typing_extensions import Self

class OrbitalTransferSimulationResponseSpacecraftStates(BaseModel):
    """
    The spacecraft states during all the simulation duration.   The timestamp of the spacecraft states depends on the orbit altitude: <ul>   <li>For LEO orbits, the spacecraft states are computed every <b>2 minutes</b>.</li>   <li>For GEO orbits, the spacecraft states are computed every <b>10 minutes</b>.</li> </ul> 
    """ # noqa: E501
    mu: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The gravitational constant of the central body")
    ephemerides_frame: Optional[StrictStr] = Field(default=None, description="The ephemerides frame", alias="ephemeridesFrame")
    timestamps: Optional[List[StrictStr]] = Field(default=None, description="The timestamps of the mean spacecraft states")
    thrusting: Optional[List[OrbitalTransferSimulationResponseSpacecraftStatesThrustingInner]] = Field(default=None, description="List of thrusting periods")
    mass: Optional[List[Union[StrictFloat, StrictInt]]] = Field(default=None, description="The mass of the spacecraft at each time step")
    mean: Optional[MeanOrOsculatingSpacecraftStates] = None
    osculating: Optional[MeanOrOsculatingSpacecraftStates] = None
    __properties: ClassVar[List[str]] = ["mu", "ephemeridesFrame", "timestamps", "thrusting", "mass", "mean", "osculating"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrbitalTransferSimulationResponseSpacecraftStates from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in thrusting (list)
        _items = []
        if self.thrusting:
            for _item in self.thrusting:
                if _item:
                    _items.append(_item.to_dict())
            _dict['thrusting'] = _items
        # override the default output from pydantic by calling `to_dict()` of mean
        if self.mean:
            _dict['mean'] = self.mean.to_dict()
        # override the default output from pydantic by calling `to_dict()` of osculating
        if self.osculating:
            _dict['osculating'] = self.osculating.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrbitalTransferSimulationResponseSpacecraftStates from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "mu": obj.get("mu"),
            "ephemeridesFrame": obj.get("ephemeridesFrame"),
            "timestamps": obj.get("timestamps"),
            "thrusting": [OrbitalTransferSimulationResponseSpacecraftStatesThrustingInner.from_dict(_item) for _item in obj["thrusting"]] if obj.get("thrusting") is not None else None,
            "mass": obj.get("mass"),
            "mean": MeanOrOsculatingSpacecraftStates.from_dict(obj["mean"]) if obj.get("mean") is not None else None,
            "osculating": MeanOrOsculatingSpacecraftStates.from_dict(obj["osculating"]) if obj.get("osculating") is not None else None
        })
        return _obj


